@@ -1,4 +1,7 @@
-class Singleton(type):
+class singleton(type):
+    """
+    A metaclass of Singleton pattern.
+    """
     _instances = {}
 
     def __call__(cls, *args, **kwargs):
